@@ -2,7 +2,7 @@
 package MooseX::Getopt::Usage;
 
 use 5.010;
-our $VERSION = '0.12_02';
+our $VERSION = '0.21_01';
 
 use Moose::Role;
 use Try::Tiny;
@@ -51,6 +51,10 @@ around new_with_options => sub {
     my @params = @_;
     my $self;
 
+    my $conf = { $class->getopt_usage_config };
+    $conf->{auto_man} = 1 if not exists $conf->{auto_man};
+    $conf->{auto_help} = 1 if not exists $conf->{auto_help};
+
     try {
         # Get in early on the arg passing to look for help or man options.
         # This makes sure they still work even when required options are missing,
@@ -58,8 +62,10 @@ around new_with_options => sub {
         # See github issue #4
         my $pa = $class->process_argv(@params);
         my $cli_params = $pa->cli_params;
-        $class->getopt_usage( man => 1)   if $class->can('man') and $cli_params->{man};
-        $class->getopt_usage( exit => 0 ) if $cli_params->{help_flag};
+        $class->getopt_usage( man => 1)
+            if $conf->{auto_man} and $class->can('man') and $cli_params->{man};
+        $class->getopt_usage( exit => 0 )
+            if $conf->{auto_help} and $cli_params->{help_flag};
 
         # Construct the object in the same way as our super new_with_options
         $self = $class->new(
@@ -104,7 +110,7 @@ MooseX::Getopt::Usage - Extend MooseX::Getopt with usage message and man page ge
 
 =head1 VERSION
 
-Version 0.12_02
+Version 0.21_01
 
 =head1 SYNOPSIS
 
@@ -255,7 +261,11 @@ Display the man page instead of the usage message.
 =head2 getopt_usage_config
 
 Return a hash (ie a list) of config to override the defaults. Default returns
-empty list. See L</CONFIGURATION> for details.
+empty list. See L</CONFIGURATION> for details of the option keys.
+
+Note that this method gets called as a class method, before the class is
+constructed. If you wish to change this method from a role you will need to use
+the around method modifier. See L</Sharing config>.
 
 =head1 CONFIGURATION
 
@@ -289,11 +299,24 @@ If no POD is found a default string of C<"%c [OPTIONS]"> is used.
 
 Note that when selecting POD the headings are removed.
 
+%a, %r and %o expand to a list of all the options on a line. %a gives all
+options, %r only required and %o only optional. Option args get square
+brackets around them, while non-boolean options get an =VALUE added. e.g. using
+a format string of "%c %r %o" might produce:
+
+ makestuff --name=NAME [--verbose] [--type=TYPE]
+
 =head2 format_sections
 
 Pod sections to select for the usage format option. Default is SYNOPSIS.
 Value is an array ref of L<Pod::Select/SECTION SPECIFICATIONS> strings.
 
+=head2 width
+
+Width to wrap output text. Default tests for a terminal, using it's width-1 if
+found (so users get usage or man that fills the terminal but wraps nicely),
+defaulting to 72 otherwise.
+
 =head2 attr_sort
 
 Sub ref used to sort the attributes and hence the order they appear in the
@@ -375,6 +398,17 @@ Set C<$Text::Wrap::unexpand>, see L<Text::Wrap/OVERRIDES>.
 
 Set C<$Text::Wrap::tabstop>, see L<Text::Wrap/OVERRIDES>.
 
+=head2 auto_man
+
+Defaults to true. Display usage when --help option is given. Set false to
+disable this, allowing you to do your own processing after new_with_options
+then probably call L<getopt_usage> yourself.
+
+=head2 auto_help
+
+Defaults to true. Display man page when --man option is given. Set false to
+disable this, allowing you to do your own processing after new_with_options
+then probably call C<< getopt_usage( man => 1,.. ) >> yourself.
 
 =head1 POD GENERATION
 
@@ -495,6 +529,46 @@ Which will look a bit like this, only in colour.
           --verbose         - Bool. Say lots about what we do
           --greet           - Str. Default=World. Who to say hello to.
 
+=head2 Sharing config
+
+You may find that you want to have a common set of config (ie
+L</getopt_usage_config> return) shared by a number of command classes. You could
+do this with a common base class or as this is Moose do it with a role.
+
+First create the role class to hold the common config:
+
+    package CommonGetoptConfig;
+    use Moose::Role;
+
+    around getopt_usage_config => sub {
+        my $orig  = shift;
+        my $class = shift;
+        return (
+            attr_sort => sub { $_[0]->name cmp $_[1]->name },
+            format => "Usage: %c [OPTIONS]",
+            headings => 0,
+            $class->$orig(@_),
+        );
+    };
+
+    1;
+
+Then in you comand class consume that role:
+
+    #!/usr/bin/env perl
+    package Hello;
+    use Moose;
+   
+    with 'MooseX::Getopt::Usage';
+    with 'CommonGetoptConfig';
+   
+    #...
+
+Note that if the consuming class also impliments getopt_usage_config then
+the configs will be combined, with config from the class overriding that from
+the role. You can change this order by moving the C<< $class->$orig(@_), >> in
+the return in the role above.
+
 
 =head1 SEE ALSO
 
@@ -524,6 +598,15 @@ Mark Pitchless, C<< <markpitchless at gmail.com> >>
 
 =head1 ACKNOWLEDGEMENTS
 
+Wayne Marquette for bug finding and pushing the use cases.
+
+ilmari+cpan@ilmari.org for patching file based tests.
+
+Tomas Doran for discussions and ideas that lead to all the pod mangling
+goodness and the big refactor at version 0.09.
+
+skazakoff for Moose bug fixes.
+
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2012 Mark Pitchless
