@@ -1,7 +1,7 @@
 package MooseX::Getopt::Usage::Formatter;
 
 use 5.010;
-our $VERSION = '0.12_02';
+our $VERSION = '0.21_01';
 
 use Moose;
 #use MooseX::StrictConstructor;
@@ -64,16 +64,15 @@ has pod_file => (
 
 sub _build_pod_file {
     my $self = shift;
+
+    # Script file, may have inline pod docs
+    my $file = "$FindBin::Bin/$FindBin::Script";
+    return $file if -f $file && contains_pod($file);
+
+    # Use the pod docs from the class
     my $gclass = $self->getopt_class;
-    if ( is_loaded($gclass) ) {
-        return pod_where( {-inc => 1}, $gclass );
-    }
-    else {
-        # Class doesn't seem to be loaded (used) so try the script file. E.g. a
-        # class definition and main pkg runner all in one file.
-        my $file = "$FindBin::Bin/$FindBin::Script";
-        return $file if -f $file && contains_pod($file);
-    }
+    return pod_where( {-inc => 1}, $gclass ) if is_loaded($gclass);
+
     return undef;
 }
 
@@ -122,6 +121,23 @@ sub _build_format {
     return $selected ? $selected : "%c [OPTIONS]";
 }
 
+has width => (
+    is      => "rw",
+    isa     => "Int",
+    lazy_build => 1,
+);
+
+sub _build_width {
+    my $self = shift;
+    my $w = 72;
+    if (-t STDOUT) {
+        my ($tw) = GetTerminalSize();
+        $w = $tw -1 if defined $tw;
+    }
+    return $w;
+}
+
+
 has attr_sort => (
     is      => "rw",
     isa     => "CodeRef",
@@ -202,6 +218,7 @@ sub usage {
         options_style => 'text',
     );
     my $parser = MooseX::Getopt::Usage::Pod::Text->new(
+        width    => $self->width,
         headings => $self->headings
     );
     my $out;
@@ -357,6 +374,9 @@ sub _parse_format {
     my $colours = $self->colours;
 
     $fmt =~ s/%c/colored $colours->{command}, prog_name()/ieg;
+    $fmt =~ s/%a/$self->_format_opt_line('a')/ieg;
+    $fmt =~ s/%r/$self->_format_opt_line('r')/ieg;
+    $fmt =~ s/%o/$self->_format_opt_line('o')/ieg;
     $fmt =~ s/%%/%/g;
     # TODO - Be good to have a include that generates a list of the opts
     #        %r - required  %a - all  %o - options
@@ -365,6 +385,44 @@ sub _parse_format {
     return $fmt;
 }
 
+sub _format_opt_line {
+    my $self = shift;
+    my $group = shift;
+
+    my @attrs;
+    if ( !$group || $group eq "a" ) {
+        @attrs = $self->_getopt_attrs;
+    }
+    elsif ( $group eq "r" ) {
+        @attrs = grep {
+            $_->is_required && !$_->has_default && !$_->has_builder
+        } $self->_getopt_attrs;
+    }
+    elsif ( $group eq "o" ) {
+        @attrs = grep {
+            !($_->is_required && !$_->has_default && !$_->has_builder)
+        } $self->_getopt_attrs;
+    }
+    else {
+        confess "Unknown grouping: $group";
+    }
+
+    my @out;
+    foreach my $attr (@attrs) {
+        my $opt = "";
+        my $label = $self->_attr_label($attr);
+        $opt .= "$label";
+        if ( not $attr->type_constraint->is_a_type_of("Bool") ) {
+            $opt .= "=".uc($attr->name)
+        }
+        if (!$attr->is_required || $attr->has_default || $attr->has_builder) {
+            $opt = "[$opt]";
+        }
+        push @out, $opt;
+    }
+    return join(" ", @out);;
+}
+
 # Return the full label, including aliases and dashes, for the passed attribute
 sub _attr_label {
     my $self   = shift;
@@ -387,12 +445,7 @@ sub _attr_str {
     my $indent  = $args{indent} || 0;
     my $colours = $self->colours;
 
-    my $w = 72;
-    if (-t STDOUT) {
-        my ($tw) = GetTerminalSize();
-        $w = $tw -1 if defined $tw;
-    }
-    local $Text::Wrap::columns  = $w;
+    local $Text::Wrap::columns  = $self->width;
     local $Text::Wrap::unexpand = $self->unexpand;
     local $Text::Wrap::tabstop  = $self->tabstop;
 
@@ -421,7 +474,7 @@ sub _colourise {
     my $colours = $self->colours;
 
     my $str = ref $out ? $out : \$out;
-    $$str =~ s/((?:^|\s)--?[\w?]+)/colored $colours->{flag}, "$1"/ge;
+    $$str =~ s/(^|\s|\[)(--?[\w?]+)/"$1".colored $colours->{flag},"$2"/ge;
     return ref $out ? $out : $$str;
 }
 
